@@ -68,9 +68,6 @@ class AppTestRun:
     def initialize(self, args):
         asset_id = args.asset_id
 
-        os.environ["LOGGING_ASSET_ID"] = str(asset_id)
-        os.environ["LOGGING_LEVEL"] = "off"
-
         start_timestamp = args.start_timestamp
         end_timestamp = args.end_timestamp
         step = args.timestep
